#include "../uemf.h"
#include "../wsIntrn.h"

#include "loopback.h"

#ifdef LOOPBACK_TEST

/*
 * Our http-client callback called on our registered events.
 * 'data' could be used for instance data (not needed here).
 */
static void http_handler (int sock, int mask, int data)
{
  if (mask & SOCKET_READABLE)
  {
    char buf[WEBS_BUFSIZE];
    int  len = socketRead (sock, buf, sizeof(buf)-1);

    if (len > 0)
    {
      buf [len] = '\0';
      fputs (buf, stderr);
    }
    else if (socketEof(sock))
    {
      trace (2, T("LOOP: got EOF\n"));
      socketCloseConnection (sock);
    }
  }
}

/*
 * Test HTTP access from loopback address 127.0.0.1
 * Open a TCP-socket at port 80, send the URL.
 */
int http_client (const char_t  *method,
                 const char_t  *uri,
                 const char_t **ext_list)
{
  char  buf [WEBS_BUFSIZE], *p = buf;
  char *host = "127.0.0.1";
  int   sock;

  sock = socketOpenConnection (host, HTTP_PORT, NULL, SOCKET_BLOCK);
  if (sock < 0)
  {
    trace (2, T("LOOP: connection on port %d failed\n"), HTTP_PORT);
    return (-1);
  }

  /* Register a callback for our socket.
   */
  socketCreateHandler (sock, SOCKET_READABLE, http_handler, 0);

  p += sprintf (p, "%s %s HTTP/1.0\r\n", (char*)method, (char*)uri);

  /* walk the extension list
   */
  while (ext_list && *ext_list)
        p += sprintf (p, "%s\r\n", (char*)(*ext_list++));

  strcat (p, "\r\n");

  trace (2, T("LOOP: Sending request: `%s'\n"), buf);

  if (socketWriteString (sock, buf) < 0)
  {
    trace (0, T("LOOP: writing request failed; %s\n"),
           strerror(socketGetError()));
    return (-1);
  }
  socketFlush (sock);
  return (sock);
}
#endif
