/*
 * socket.c -- Socket support module for Watt-32/djgpp
 *
 * Copyright (c) Go Ahead, 1995-1999
 *
 * Modifications for Watt-32 by G. Vanem <giva@bgnett.no> Aug-1999
 */

/******************************** Description *********************************/

/*
 *    SCO Unix Socket Module.  This supports non-blocking buffered socket I/O.
 */

/********************************** Includes **********************************/

#include    <errno.h>
#include    <fcntl.h>
#include    <string.h>
#include    <stdlib.h>
#include    <unistd.h>
#include    <sys/ioctl.h>
#include    <tcp.h>     /* Watt-32 main header */

#include    "../uemf.h"

/*********************************** Defines **********************************/

typedef struct {
    char            host[64];          /* Host name */
    ringq_t         inBuf;             /* Input ring queue */
    ringq_t         outBuf;            /* Output ring queue */
    ringq_t         lineBuf;           /* Line ring queue */
    socketAccept_t  accept;            /* Accept handler */
    socketHandler_t handler;           /* User I/O handler */
    int             handler_data;      /* User handler data */
    int             sid;               /* Index into socket[] */
    int             port;              /* Port to listen on */
    int             flags;             /* Current state flags */
    int             readyMask;         /* Events now ready */
    int             interestMask;      /* Events interest */
    int             error;             /* Last error */
    int             sock;              /* Actual socket handle */
} socket_t;

/************************************ Locals **********************************/

static socket_t **socketList;           /* List of open sockets */
static int        socketMax;            /* Maximum size of socket */
static int        socketHighestFd = -1; /* Highest socket fd opened */

/***************************** Forward Declarations ***************************/

static int socketDoEvent(socket_t *sp);
static int socketNonBlock(socket_t *sp);


/******************************************************************************/
/*
 *    Put the socket into non-blocking mode
 */

static int socketNonBlock(socket_t *sp)
{
#if 1
   char on = 1;
   return ioctlsocket (sp->sock, FIONBIO, &on);
#else
   return (0); /* okay */
#endif
}
